@@ -1,7 +1,7 @@
 /*
  * isi2xml.c
  *
- * Copyright (c) Chris Putnam 2004-2013
+ * Copyright (c) Chris Putnam 2004-2018
  *
  * Program and source code released under the GPL version 2
  *
@@ -9,8 +9,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include "bibutils.h"
-#include "isiin.h"
-#include "modsout.h"
+#include "bibformats.h"
 #include "tomods.h"
 #include "bibprog.h"
 
